# Load packages
library(multcompView)
library(piecewiseSEM)
library(nlme)


##load data
NEON_stab.data <-  read.csv('sem_quadrat.csv',fileEncoding = "Latin1", check.names = F)
NEON_stab.data$Richness<- log(with(NEON_stab.data,Richness))
NEON_stab.data$Inverse_Simpson<- log(with(NEON_stab.data,Inverse_Simpson))
NEON_stab.data$Beta_diversity<- log(with(NEON_stab.data,Beta_diversity))
NEON_stab.data$Species_nestedness<- log(with(NEON_stab.data,Species_nestedness))
NEON_stab.data$Species_turnover<- log(with(NEON_stab.data,Species_turnover))
NEON_stab.data$Evenness<- log(with(NEON_stab.data,Evenness))
# check variables
variable.names(NEON_stab.data)
##############################################################################################################
[1] "no"                 "site"               "treatment"          "Richness"           "Evenness"           "Inverse_Simpson"    "Beta_diversity"     "Species_turnover"  
[9] "Species_nestedness"    
##############################################################################################################

############################################
SEM_env1.m <-psem(
  
  lme(Beta_diversity~Species_turnover+treatment+Species_nestedness+Evenness,random=~1|site,data=NEON_stab.data), # empirical relationships
  lme(Species_turnover~Evenness+treatment,random=~1|site,data=NEON_stab.data), 
  lme(Richness~treatment, random=~1|site,data=NEON_stab.data), # empirical relationships
  lme(Evenness~Richness+treatment,random=~1|site,data=NEON_stab.data), # mathematical relationships, r2 = 1.00
  lme(Species_nestedness~treatment+Evenness, random=~1|site,data=NEON_stab.data), # mathematical relationships, r2 = 1.00
  Species_turnover%~~%Species_nestedness, # a mathematical relationship
  Evenness%~~%Richness, 
  data=NEON_stab.data)

plot(SEM_env1.m )
# To evaluate the model
summary(SEM_env1.m) # Note that there were non-significant pathways.
fisherC(SEM_env1.m) # Note that SEM_env1.m was still unsaturated (Fisher.c > df) and its significant estimations were very well with p > 0.05.
AIC(SEM_env1.m)
